@@ -59,9 +59,9 @@
 #include <stdio.h>
 #include <ctype.h>
 #include "cryptlib.h"
-#include "lhash.h"
-#include "asn1.h"
-#include "objects.h"
+#include <openssl/lhash.h>
+#include <openssl/asn1.h>
+#include <openssl/objects.h>
 
 /* obj_dat.h is generated from objects.h by obj_dat.pl */
 #ifndef NO_OBJECT
@@ -79,16 +79,9 @@ static ASN1_OBJECT *ln_objs[1];
 static ASN1_OBJECT *obj_objs[1];
 #endif
 
-#ifndef NOPROTO
 static int sn_cmp(ASN1_OBJECT **a, ASN1_OBJECT **b);
 static int ln_cmp(ASN1_OBJECT **a, ASN1_OBJECT **b);
 static int obj_cmp(ASN1_OBJECT **a, ASN1_OBJECT **b);
-#else
-static int sn_cmp();
-static int ln_cmp();
-static int obj_cmp();
-#endif
-
 #define ADDED_DATA	0
 #define ADDED_SNAME	1
 #define ADDED_LNAME	2
@@ -103,18 +96,13 @@ typedef struct added_obj_st
 static int new_nid=NUM_NID;
 static LHASH *added=NULL;
 
-static int sn_cmp(ap,bp)
-ASN1_OBJECT **ap;
-ASN1_OBJECT **bp;
+static int sn_cmp(ASN1_OBJECT **ap, ASN1_OBJECT **bp)
 	{ return(strcmp((*ap)->sn,(*bp)->sn)); }
 
-static int ln_cmp(ap,bp)
-ASN1_OBJECT **ap;
-ASN1_OBJECT **bp;
+static int ln_cmp(ASN1_OBJECT **ap, ASN1_OBJECT **bp)
 	{ return(strcmp((*ap)->ln,(*bp)->ln)); }
 
-static unsigned long add_hash(ca)
-ADDED_OBJ *ca;
+static unsigned long add_hash(ADDED_OBJ *ca)
 	{
 	ASN1_OBJECT *a;
 	int i;
@@ -147,8 +135,7 @@ ADDED_OBJ *ca;
 	return(ret);
 	}
 
-static int add_cmp(ca,cb)
-ADDED_OBJ *ca,*cb;
+static int add_cmp(ADDED_OBJ *ca, ADDED_OBJ *cb)
 	{
 	ASN1_OBJECT *a,*b;
 	int i;
@@ -179,15 +166,14 @@ ADDED_OBJ *ca,*cb;
 	return(1); /* should not get here */
 	}
 
-static int init_added()
+static int init_added(void)
 	{
 	if (added != NULL) return(1);
 	added=lh_new(add_hash,add_cmp);
 	return(added != NULL);
 	}
 
-static void cleanup1(a)
-ADDED_OBJ *a;
+static void cleanup1(ADDED_OBJ *a)
 	{
 	a->obj->nid=0;
 	a->obj->flags|=ASN1_OBJECT_FLAG_DYNAMIC|
@@ -195,19 +181,17 @@ ADDED_OBJ *a;
 			ASN1_OBJECT_FLAG_DYNAMIC_DATA;
 	}
 
-static void cleanup2(a)
-ADDED_OBJ *a;
+static void cleanup2(ADDED_OBJ *a)
 	{ a->obj->nid++; }
 
-static void cleanup3(a)
-ADDED_OBJ *a;
+static void cleanup3(ADDED_OBJ *a)
 	{
 	if (--a->obj->nid == 0)
 		ASN1_OBJECT_free(a->obj);
 	Free(a);
 	}
 
-void OBJ_cleanup()
+void OBJ_cleanup(void)
 	{
 	if (added == NULL) return;
 	added->down_load=0;
@@ -218,8 +202,7 @@ void OBJ_cleanup()
 	added=NULL;
 	}
 
-int OBJ_new_nid(num)
-int num;
+int OBJ_new_nid(int num)
 	{
 	int i;
 
@@ -228,8 +211,7 @@ int num;
 	return(i);
 	}
 
-int OBJ_add_object(obj)
-ASN1_OBJECT *obj;
+int OBJ_add_object(ASN1_OBJECT *obj)
 	{
 	ASN1_OBJECT *o;
 	ADDED_OBJ *ao[4],*aop;
@@ -273,8 +255,7 @@ err:
 	return(NID_undef);
 	}
 
-ASN1_OBJECT *OBJ_nid2obj(n)
-int n;
+ASN1_OBJECT *OBJ_nid2obj(int n)
 	{
 	ADDED_OBJ ad,*adp;
 	ASN1_OBJECT ob;
@@ -306,8 +287,7 @@ int n;
 		}
 	}
 
-char *OBJ_nid2sn(n)
-int n;
+const char *OBJ_nid2sn(int n)
 	{
 	ADDED_OBJ ad,*adp;
 	ASN1_OBJECT ob;
@@ -339,8 +319,7 @@ int n;
 		}
 	}
 
-char *OBJ_nid2ln(n)
-int n;
+const char *OBJ_nid2ln(int n)
 	{
 	ADDED_OBJ ad,*adp;
 	ASN1_OBJECT ob;
@@ -372,8 +351,7 @@ int n;
 		}
 	}
 
-int OBJ_obj2nid(a)
-ASN1_OBJECT *a;
+int OBJ_obj2nid(ASN1_OBJECT *a)
 	{
 	ASN1_OBJECT **op;
 	ADDED_OBJ ad,*adp;
@@ -403,9 +381,7 @@ ASN1_OBJECT *a;
  * it can be used with any objects, not just registered ones.
  */
 
-ASN1_OBJECT *OBJ_txt2obj(s, no_name)
-char *s;
-int no_name;
+ASN1_OBJECT *OBJ_txt2obj(const char *s, int no_name)
 	{
 	int nid = NID_undef;
 	ASN1_OBJECT *op=NULL;
@@ -442,8 +418,7 @@ int no_name;
 	return op;
 	}
 
-int OBJ_txt2nid(s)
-char *s;
+int OBJ_txt2nid(char *s)
 {
 	ASN1_OBJECT *obj;
 	int nid;
@@ -453,8 +428,7 @@ char *s;
 	return nid;
 }
 
-int OBJ_ln2nid(s)
-char *s;
+int OBJ_ln2nid(const char *s)
 	{
 	ASN1_OBJECT o,*oo= &o,**op;
 	ADDED_OBJ ad,*adp;
@@ -473,8 +447,7 @@ char *s;
 	return((*op)->nid);
 	}
 
-int OBJ_sn2nid(s)
-char *s;
+int OBJ_sn2nid(const char *s)
 	{
 	ASN1_OBJECT o,*oo= &o,**op;
 	ADDED_OBJ ad,*adp;
@@ -493,9 +466,7 @@ char *s;
 	return((*op)->nid);
 	}
 
-static int obj_cmp(ap, bp)
-ASN1_OBJECT **ap;
-ASN1_OBJECT **bp;
+static int obj_cmp(ASN1_OBJECT **ap, ASN1_OBJECT **bp)
 	{
 	int j;
 	ASN1_OBJECT *a= *ap;
@@ -506,12 +477,7 @@ ASN1_OBJECT **bp;
 	return(memcmp(a->data,b->data,a->length));
         }
 
-char *OBJ_bsearch(key,base,num,size,cmp)
-char *key;
-char *base;
-int num;
-int size;
-int (*cmp)();
+char *OBJ_bsearch(char *key, char *base, int num, int size, int (*cmp)())
 	{
 	int l,h,i,c;
 	char *p;
@@ -534,8 +500,7 @@ int (*cmp)();
 	return(NULL);
 	}
 
-int OBJ_create_objects(in)
-BIO *in;
+int OBJ_create_objects(BIO *in)
 	{
 	MS_STATIC char buf[512];
 	int i,num=0;
@@ -547,26 +512,26 @@ BIO *in;
 		i=BIO_gets(in,buf,512);
 		if (i <= 0) return(num);
 		buf[i-1]='\0';
-		if (!isalnum(buf[0])) return(num);
+		if (!isalnum((unsigned char)buf[0])) return(num);
 		o=s=buf;
-		while (isdigit(*s) || (*s == '.'))
+		while (isdigit((unsigned char)*s) || (*s == '.'))
 			s++;
 		if (*s != '\0')
 			{
 			*(s++)='\0';
-			while (isspace(*s))
+			while (isspace((unsigned char)*s))
 				s++;
 			if (*s == '\0')
 				s=NULL;
 			else
 				{
 				l=s;
-				while ((*l != '\0') && !isspace(*l))
+				while ((*l != '\0') && !isspace((unsigned char)*l))
 					l++;
 				if (*l != '\0')
 					{
 					*(l++)='\0';
-					while (isspace(*l))
+					while (isspace((unsigned char)*l))
 						l++;
 					if (*l == '\0') l=NULL;
 					}
@@ -583,10 +548,7 @@ BIO *in;
 	/* return(num); */
 	}
 
-int OBJ_create(oid,sn,ln)
-char *oid;
-char *sn;
-char *ln;
+int OBJ_create(char *oid, char *sn, char *ln)
 	{
 	int ok=0;
 	ASN1_OBJECT *op=NULL;
