@@ -60,17 +60,15 @@
 #include <stdlib.h>
 #include <string.h>
 #include "cryptlib.h"
-#include "buffer.h"
-#include "txt_db.h"
+#include <openssl/buffer.h>
+#include <openssl/txt_db.h>
 
 #undef BUFSIZE
 #define BUFSIZE	512
 
-char *TXT_DB_version="TXT_DB" OPENSSL_VERSION_PTEXT;
+const char *TXT_DB_version="TXT_DB" OPENSSL_VERSION_PTEXT;
 
-TXT_DB *TXT_DB_read(in,num)
-BIO *in;
-int num;
+TXT_DB *TXT_DB_read(BIO *in, int num)
 	{
 	TXT_DB *ret=NULL;
 	int er=1;
@@ -191,10 +189,7 @@ err:
 		return(ret);
 	}
 
-char **TXT_DB_get_by_index(db,idx,value)
-TXT_DB *db;
-int idx;
-char **value;
+char **TXT_DB_get_by_index(TXT_DB *db, int idx, char **value)
 	{
 	char **ret;
 	LHASH *lh;
@@ -215,12 +210,8 @@ char **value;
 	return(ret);
 	}
 
-int TXT_DB_create_index(db,field,qual,hash,cmp)
-TXT_DB *db;
-int field;
-int (*qual)();
-unsigned long (*hash)();
-int (*cmp)();
+int TXT_DB_create_index(TXT_DB *db, int field, int (*qual)(),
+	     unsigned long (*hash)(), int (*cmp)())
 	{
 	LHASH *idx;
 	char *r;
@@ -256,9 +247,7 @@ int (*cmp)();
 	return(1);
 	}
 
-long TXT_DB_write(out,db)
-BIO *out;
-TXT_DB *db;
+long TXT_DB_write(BIO *out, TXT_DB *db)
 	{
 	long i,j,n,nn,l,tot=0;
 	char *p,**pp,*f;
@@ -306,9 +295,7 @@ err:
 	return(ret);
 	}
 
-int TXT_DB_insert(db,row)
-TXT_DB *db;
-char **row;
+int TXT_DB_insert(TXT_DB *db, char **row)
 	{
 	int i;
 	char **r;
@@ -350,8 +337,7 @@ err:
 	return(0);
 	}
 
-void TXT_DB_free(db)
-TXT_DB *db;
+void TXT_DB_free(TXT_DB *db)
 	{
 	int i,n;
 	char **p,*max;
