@@ -24,7 +24,7 @@ SEXP R_cert_info(SEXP bin){
   //subject name
   name = X509_get_subject_name(cert);
   b = BIO_new(BIO_s_mem());
-  bail(X509_NAME_print_ex(b, name, 0, XN_FLAG_ONELINE & ~ASN1_STRFLGS_ESC_MSB));
+  bail(X509_NAME_print_ex(b, name, 0, XN_FLAG_RFC2253 & ~ASN1_STRFLGS_ESC_MSB));
   len = BIO_read(b, buf, bufsize);
   BIO_free(b);
   SET_VECTOR_ELT(out, 0, allocVector(STRSXP, 1));
@@ -34,7 +34,7 @@ SEXP R_cert_info(SEXP bin){
   //issuer name name
   name = X509_get_issuer_name(cert);
   b = BIO_new(BIO_s_mem());
-  bail(X509_NAME_print_ex(b, name, 0, XN_FLAG_ONELINE & ~ASN1_STRFLGS_ESC_MSB));
+  bail(X509_NAME_print_ex(b, name, 0, XN_FLAG_RFC2253 & ~ASN1_STRFLGS_ESC_MSB));
   len = BIO_read(b, buf, bufsize);
   BIO_free(b);
   SET_VECTOR_ELT(out, 1, allocVector(STRSXP, 1));
