@@ -59,24 +59,25 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "e_os.h"
-#include "bio.h"
-#include "bn.h"
-#include "rand.h"
-#include "x509.h"
-#include "err.h"
+
+#include "openssl/e_os.h"
+
+#include <openssl/bio.h>
+#include <openssl/bn.h>
+#include <openssl/rand.h>
+#include <openssl/x509.h>
+#include <openssl/err.h>
 
 #ifdef WINDOWS
 #include "../bio/bss_file.c"
 #endif
 
-#ifndef NOPROTO
 int test_add(BIO *bp);
 int test_sub(BIO *bp);
 int test_lshift1(BIO *bp);
-int test_lshift(BIO *bp);
+int test_lshift(BIO *bp,BN_CTX *ctx,BIGNUM *a_);
 int test_rshift1(BIO *bp);
-int test_rshift(BIO *bp);
+int test_rshift(BIO *bp,BN_CTX *ctx);
 int test_div(BIO *bp,BN_CTX *ctx);
 int test_div_recp(BIO *bp,BN_CTX *ctx);
 int test_mul(BIO *bp);
@@ -87,24 +88,6 @@ int test_mod_mul(BIO *bp,BN_CTX *ctx);
 int test_mod_exp(BIO *bp,BN_CTX *ctx);
 int test_exp(BIO *bp,BN_CTX *ctx);
 int rand_neg(void);
-#else
-int test_add ();
-int test_sub ();
-int test_lshift1 ();
-int test_lshift ();
-int test_rshift1 ();
-int test_rshift ();
-int test_div ();
-int test_mul ();
-int test_sqr ();
-int test_mont ();
-int test_mod ();
-int test_mod_mul ();
-int test_mod_exp ();
-int test_exp ();
-int rand_neg();
-#endif
-
 static int results=0;
 
 #ifdef NO_STDIO
@@ -112,9 +95,10 @@ static int results=0;
 #include "bss_file.c"
 #endif
 
-int main(argc,argv)
-int argc;
-char *argv[];
+static unsigned char lst1[]="\xC6\x4F\x43\x04\x2A\xEA\xCA\x6E\x58\x36\x80\x5B\xE8\xC9"
+"\x9B\x04\x5D\x48\x36\xC2\xFD\x16\xC9\x64\xF0";
+
+int main(int argc, char *argv[])
 	{
 	BN_CTX *ctx;
 	BIO *out;
@@ -171,8 +155,13 @@ char *argv[];
 	if (!test_lshift1(out)) goto err;
 	fflush(stdout);
 
+	fprintf(stderr,"test BN_lshift (fixed)\n");
+	if (!test_lshift(out,ctx,BN_bin2bn(lst1,sizeof(lst1)-1,NULL)))
+	    goto err;
+	fflush(stdout);
+
 	fprintf(stderr,"test BN_lshift\n");
-	if (!test_lshift(out)) goto err;
+	if (!test_lshift(out,ctx,NULL)) goto err;
 	fflush(stdout);
 
 	fprintf(stderr,"test BN_rshift1\n");
@@ -180,7 +169,7 @@ char *argv[];
 	fflush(stdout);
 
 	fprintf(stderr,"test BN_rshift\n");
-	if (!test_rshift(out)) goto err;
+	if (!test_rshift(out,ctx)) goto err;
 	fflush(stdout);
 
 	fprintf(stderr,"test BN_sqr\n");
@@ -229,8 +218,7 @@ err:
 	return(1);
 	}
 
-int test_add(bp)
-BIO *bp;
+int test_add(BIO *bp)
 	{
 	BIGNUM a,b,c;
 	int i;
@@ -262,6 +250,15 @@ BIO *bp;
 			BN_print(bp,&c);
 			BIO_puts(bp,"\n");
 			}
+		a.neg=!a.neg;
+		b.neg=!b.neg;
+		BN_add(&c,&c,&b);
+		BN_add(&c,&c,&a);
+		if(!BN_is_zero(&c))
+		    {
+		    BIO_puts(bp,"Add test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(&a);
 	BN_free(&b);
@@ -269,8 +266,7 @@ BIO *bp;
 	return(1);
 	}
 
-int test_sub(bp)
-BIO *bp;
+int test_sub(BIO *bp)
 	{
 	BIGNUM a,b,c;
 	int i;
@@ -302,6 +298,13 @@ BIO *bp;
 			BN_print(bp,&c);
 			BIO_puts(bp,"\n");
 			}
+		BN_add(&c,&c,&b);
+		BN_sub(&c,&c,&a);
+		if(!BN_is_zero(&c))
+		    {
+		    BIO_puts(bp,"Subtract test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(&a);
 	BN_free(&b);
@@ -309,11 +312,9 @@ BIO *bp;
 	return(1);
 	}
 
-int test_div(bp,ctx)
-BIO *bp;
-BN_CTX *ctx;
+int test_div(BIO *bp, BN_CTX *ctx)
 	{
-	BIGNUM a,b,c,d;
+	BIGNUM a,b,c,d,e;
 	int i;
 	int j;
 
@@ -321,6 +322,7 @@ BN_CTX *ctx;
 	BN_init(&b);
 	BN_init(&c);
 	BN_init(&d);
+	BN_init(&e);
 
 	BN_rand(&a,400,0,0);
 	for (i=0; i<100; i++)
@@ -354,19 +356,26 @@ BN_CTX *ctx;
 			BN_print(bp,&c);
 			BIO_puts(bp,"\n");
 			}
+		BN_mul(&e,&d,&b,ctx);
+		BN_add(&d,&e,&c);
+		BN_sub(&d,&d,&a);
+		if(!BN_is_zero(&d))
+		    {
+		    BIO_puts(bp,"Division test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(&a);
 	BN_free(&b);
 	BN_free(&c);
 	BN_free(&d);
+	BN_free(&e);
 	return(1);
 	}
 
-int test_div_recp(bp,ctx)
-BIO *bp;
-BN_CTX *ctx;
+int test_div_recp(BIO *bp, BN_CTX *ctx)
 	{
-	BIGNUM a,b,c,d;
+	BIGNUM a,b,c,d,e;
 	BN_RECP_CTX recp;
 	int i;
 	int j;
@@ -376,6 +385,7 @@ BN_CTX *ctx;
 	BN_init(&b);
 	BN_init(&c);
 	BN_init(&d);
+	BN_init(&e);
 
 	BN_rand(&a,400,0,0);
 	for (i=0; i<100; i++)
@@ -410,19 +420,27 @@ BN_CTX *ctx;
 			BN_print(bp,&c);
 			BIO_puts(bp,"\n");
 			}
+		BN_mul(&e,&d,&b,ctx);
+		BN_add(&d,&e,&c);
+		BN_sub(&d,&d,&a);
+		if(!BN_is_zero(&d))
+		    {
+		    BIO_puts(bp,"Reciprocal division test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(&a);
 	BN_free(&b);
 	BN_free(&c);
 	BN_free(&d);
+	BN_free(&e);
 	BN_RECP_CTX_free(&recp);
 	return(1);
 	}
 
-int test_mul(bp)
-BIO *bp;
+int test_mul(BIO *bp)
 	{
-	BIGNUM a,b,c;
+	BIGNUM a,b,c,d,e;
 	int i;
 	int j;
 	BN_CTX ctx;
@@ -431,6 +449,8 @@ BIO *bp;
 	BN_init(&a);
 	BN_init(&b);
 	BN_init(&c);
+	BN_init(&d);
+	BN_init(&e);
 
 	BN_rand(&a,200,0,0);
 	for (i=0; i<100; i++)
@@ -443,7 +463,6 @@ BIO *bp;
 			for (j=0; j<100; j++)
 				BN_mul(&c,&a,&b,&ctx);
 		BN_mul(&c,&a,&b,&ctx);
-/*bn_do(&c,&a,&b,ctx); */
 		if (bp != NULL)
 			{
 			if (!results)
@@ -456,24 +475,33 @@ BIO *bp;
 			BN_print(bp,&c);
 			BIO_puts(bp,"\n");
 			}
+		BN_div(&d,&e,&c,&a,&ctx);
+		BN_sub(&d,&d,&b);
+		if(!BN_is_zero(&d) || !BN_is_zero(&e))
+		    {
+		    BIO_puts(bp,"Multiplication test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(&a);
 	BN_free(&b);
 	BN_free(&c);
+	BN_free(&d);
+	BN_free(&e);
 	BN_CTX_free(&ctx);
 	return(1);
 	}
 
-int test_sqr(bp,ctx)
-BIO *bp;
-BN_CTX *ctx;
+int test_sqr(BIO *bp, BN_CTX *ctx)
 	{
-	BIGNUM a,c;
+	BIGNUM a,c,d,e;
 	int i;
 	int j;
 
 	BN_init(&a);
 	BN_init(&c);
+	BN_init(&d);
+	BN_init(&e);
 
 	for (i=0; i<40; i++)
 		{
@@ -495,17 +523,24 @@ BN_CTX *ctx;
 			BN_print(bp,&c);
 			BIO_puts(bp,"\n");
 			}
+		BN_div(&d,&e,&c,&a,ctx);
+		BN_sub(&d,&d,&a);
+		if(!BN_is_zero(&d) || !BN_is_zero(&e))
+		    {
+		    BIO_puts(bp,"Square test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(&a);
 	BN_free(&c);
+	BN_free(&d);
+	BN_free(&e);
 	return(1);
 	}
 
-int test_mont(bp,ctx)
-BIO *bp;
-BN_CTX *ctx;
+int test_mont(BIO *bp, BN_CTX *ctx)
 	{
-	BIGNUM a,b,c,A,B;
+	BIGNUM a,b,c,d,A,B;
 	BIGNUM n;
 	int i;
 	int j;
@@ -514,6 +549,7 @@ BN_CTX *ctx;
 	BN_init(&a);
 	BN_init(&b);
 	BN_init(&c);
+	BN_init(&d);
 	BN_init(&A);
 	BN_init(&B);
 	BN_init(&n);
@@ -555,25 +591,36 @@ BN_num_bits(mont->N));
 			BN_print(bp,&A);
 			BIO_puts(bp,"\n");
 			}
+		BN_mod_mul(&d,&a,&b,&n,ctx);
+		BN_sub(&d,&d,&A);
+		if(!BN_is_zero(&d))
+		    {
+		    BIO_puts(bp,"Montgomery multiplication test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_MONT_CTX_free(mont);
 	BN_free(&a);
 	BN_free(&b);
 	BN_free(&c);
+	BN_free(&d);
+	BN_free(&A);
+	BN_free(&B);
+	BN_free(&n);
 	return(1);
 	}
 
-int test_mod(bp,ctx)
-BIO *bp;
-BN_CTX *ctx;
+int test_mod(BIO *bp, BN_CTX *ctx)
 	{
-	BIGNUM *a,*b,*c;
+	BIGNUM *a,*b,*c,*d,*e;
 	int i;
 	int j;
 
 	a=BN_new();
 	b=BN_new();
 	c=BN_new();
+	d=BN_new();
+	e=BN_new();
 
 	BN_rand(a,1024,0,0); /**/
 	for (i=0; i<20; i++)
@@ -597,16 +644,23 @@ BN_CTX *ctx;
 			BN_print(bp,c);
 			BIO_puts(bp,"\n");
 			}
+		BN_div(d,e,a,b,ctx);
+		BN_sub(e,e,c);
+		if(!BN_is_zero(e))
+		    {
+		    BIO_puts(bp,"Modulo test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(a);
 	BN_free(b);
 	BN_free(c);
+	BN_free(d);
+	BN_free(e);
 	return(1);
 	}
 
-int test_mod_mul(bp,ctx)
-BIO *bp;
-BN_CTX *ctx;
+int test_mod_mul(BIO *bp, BN_CTX *ctx)
 	{
 	BIGNUM *a,*b,*c,*d,*e;
 	int i;
@@ -651,6 +705,14 @@ BN_CTX *ctx;
 			BN_print(bp,e);
 			BIO_puts(bp,"\n");
 			}
+		BN_mul(d,a,b,ctx);
+		BN_sub(d,d,e);
+		BN_div(a,b,d,c,ctx);
+		if(!BN_is_zero(b))
+		    {
+		    BIO_puts(bp,"Modulo multiply test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(a);
 	BN_free(b);
@@ -660,9 +722,7 @@ BN_CTX *ctx;
 	return(1);
 	}
 
-int test_mod_exp(bp,ctx)
-BIO *bp;
-BN_CTX *ctx;
+int test_mod_exp(BIO *bp, BN_CTX *ctx)
 	{
 	BIGNUM *a,*b,*c,*d,*e;
 	int i;
@@ -696,6 +756,14 @@ BN_CTX *ctx;
 			BN_print(bp,d);
 			BIO_puts(bp,"\n");
 			}
+		BN_exp(e,a,b,ctx);
+		BN_sub(e,e,d);
+		BN_div(a,b,e,c,ctx);
+		if(!BN_is_zero(b))
+		    {
+		    BIO_puts(bp,"Modulo exponentiation test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(a);
 	BN_free(b);
@@ -705,17 +773,17 @@ BN_CTX *ctx;
 	return(1);
 	}
 
-int test_exp(bp,ctx)
-BIO *bp;
-BN_CTX *ctx;
+int test_exp(BIO *bp, BN_CTX *ctx)
 	{
-	BIGNUM *a,*b,*d,*e;
+	BIGNUM *a,*b,*d,*e,*one;
 	int i;
 
 	a=BN_new();
 	b=BN_new();
 	d=BN_new();
 	e=BN_new();
+	one=BN_new();
+	BN_one(one);
 
 	for (i=0; i<6; i++)
 		{
@@ -737,27 +805,42 @@ BN_CTX *ctx;
 			BN_print(bp,d);
 			BIO_puts(bp,"\n");
 			}
+		BN_one(e);
+		for( ; !BN_is_zero(b) ; BN_sub(b,b,one))
+		    BN_mul(e,e,a,ctx);
+		BN_sub(e,e,d);
+		if(!BN_is_zero(e))
+		    {
+		    BIO_puts(bp,"Exponentiation test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(a);
 	BN_free(b);
 	BN_free(d);
 	BN_free(e);
+	BN_free(one);
 	return(1);
 	}
 
-int test_lshift(bp)
-BIO *bp;
+int test_lshift(BIO *bp,BN_CTX *ctx,BIGNUM *a_)
 	{
-	BIGNUM *a,*b,*c;
+	BIGNUM *a,*b,*c,*d;
 	int i;
 
-	a=BN_new();
 	b=BN_new();
 	c=BN_new();
+	d=BN_new();
 	BN_one(c);
 
-	BN_rand(a,200,0,0); /**/
-	a->neg=rand_neg();
+	if(a_)
+	    a=a_;
+	else
+	    {
+	    a=BN_new();
+	    BN_rand(a,200,0,0); /**/
+	    a->neg=rand_neg();
+	    }
 	for (i=0; i<70; i++)
 		{
 		BN_lshift(b,a,i+1);
@@ -774,21 +857,38 @@ BIO *bp;
 			BN_print(bp,b);
 			BIO_puts(bp,"\n");
 			}
+		BN_mul(d,a,c,ctx);
+		BN_sub(d,d,b);
+		if(!BN_is_zero(d))
+		    {
+		    BIO_puts(bp,"Left shift test failed!\n");
+		    BIO_puts(bp,"a=");
+		    BN_print(bp,a);
+		    BIO_puts(bp,"\nb=");
+		    BN_print(bp,b);
+		    BIO_puts(bp,"\nc=");
+		    BN_print(bp,c);
+		    BIO_puts(bp,"\nd=");
+		    BN_print(bp,d);
+		    BIO_puts(bp,"\n");
+		    return 0;
+		    }
 		}
 	BN_free(a);
 	BN_free(b);
 	BN_free(c);
+	BN_free(d);
 	return(1);
 	}
 
-int test_lshift1(bp)
-BIO *bp;
+int test_lshift1(BIO *bp)
 	{
-	BIGNUM *a,*b;
+	BIGNUM *a,*b,*c;
 	int i;
 
 	a=BN_new();
 	b=BN_new();
+	c=BN_new();
 
 	BN_rand(a,200,0,0); /**/
 	a->neg=rand_neg();
@@ -806,22 +906,32 @@ BIO *bp;
 			BN_print(bp,b);
 			BIO_puts(bp,"\n");
 			}
+		BN_add(c,a,a);
+		BN_sub(a,b,c);
+		if(!BN_is_zero(a))
+		    {
+		    BIO_puts(bp,"Left shift one test failed!\n");
+		    return 0;
+		    }
+		
 		BN_copy(a,b);
 		}
 	BN_free(a);
 	BN_free(b);
+	BN_free(c);
 	return(1);
 	}
 
-int test_rshift(bp)
-BIO *bp;
+int test_rshift(BIO *bp,BN_CTX *ctx)
 	{
-	BIGNUM *a,*b,*c;
+	BIGNUM *a,*b,*c,*d,*e;
 	int i;
 
 	a=BN_new();
 	b=BN_new();
 	c=BN_new();
+	d=BN_new();
+	e=BN_new();
 	BN_one(c);
 
 	BN_rand(a,200,0,0); /**/
@@ -842,21 +952,30 @@ BIO *bp;
 			BN_print(bp,b);
 			BIO_puts(bp,"\n");
 			}
+		BN_div(d,e,a,c,ctx);
+		BN_sub(d,d,b);
+		if(!BN_is_zero(d))
+		    {
+		    BIO_puts(bp,"Right shift test failed!\n");
+		    return 0;
+		    }
 		}
 	BN_free(a);
 	BN_free(b);
 	BN_free(c);
+	BN_free(d);
+	BN_free(e);
 	return(1);
 	}
 
-int test_rshift1(bp)
-BIO *bp;
+int test_rshift1(BIO *bp)
 	{
-	BIGNUM *a,*b;
+	BIGNUM *a,*b,*c;
 	int i;
 
 	a=BN_new();
 	b=BN_new();
+	c=BN_new();
 
 	BN_rand(a,200,0,0); /**/
 	a->neg=rand_neg();
@@ -874,14 +993,22 @@ BIO *bp;
 			BN_print(bp,b);
 			BIO_puts(bp,"\n");
 			}
+		BN_sub(c,a,b);
+		BN_sub(c,c,b);
+		if(!BN_is_zero(c) && !BN_is_one(c))
+		    {
+		    BIO_puts(bp,"Right shift one test failed!\n");
+		    return 0;
+		    }
 		BN_copy(a,b);
 		}
 	BN_free(a);
 	BN_free(b);
+	BN_free(c);
 	return(1);
 	}
 
-int rand_neg()
+int rand_neg(void)
 	{
 	static unsigned int neg=0;
 	static int sign[8]={0,0,0,1,1,0,1,1};
