@@ -1,5 +1,7 @@
 context("Test ECDSA 384 formats")
 
+if(openssl_config()$ec){
+
 # Read secret key and public key
 sk1 <- read_key("../keys/id_ecdsa384")
 pk1 <- read_pubkey("../keys/id_ecdsa384.pub")
@@ -65,3 +67,7 @@ test_that("signature path interface", {
 
 # Cleanup
 rm(sk1, pk1)
+
+} else {
+  cat("ec not supported")
+}
